@@ -10,7 +10,6 @@ class Lab5Parser(ArgumentParser):
         self.add_argument("next_player", nargs='?', default=self.calc_player(self.default_puzzle))
 
     def valid_puzzle(self, puzzle):
-        print(len(puzzle))
         return isinstance(puzzle, str) and len(puzzle) == 64
 
     def valid_player(self, player):
@@ -20,7 +19,7 @@ class Lab5Parser(ArgumentParser):
         return ["X", "O"][puzzle.count('.') % 2 == 1]
 
     def parse_args(self, args=None, namespace=None):
-        args = super(OthelloParser, self).parse_args(args, namespace)
+        args = super(Lab5Parser, self).parse_args(args, namespace)
         set_player = False
         if not self.valid_player(args.next_player):
             args.extra = [args.next_player] + args.extra
